@@ -10,7 +10,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-01-27'; # DATE
 our $DIST = 'App-BPOMUtils-RPO-Checker'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our @EXPORT_OK = qw(
                        bpom_rpo_check_label_design
@@ -57,6 +57,10 @@ sub bpom_rpo_check_label_design {
     for my $file (@{ $args{files} }) {
         $i++;
         log_info "[%d/%d] Processing file %s ...", $i, scalar(@{ $args{files} }), $file;
+        unless (-f $file) {
+            push @errors, {file=>$file, message=>"File not found or not a regular file"};
+            next;
+        }
         unless ($file =~ /\.jpe?g\z/i) {
             push @errors, {file=>$file, message=>"Filename does not end in .JPG or .JPEG"};
         }
@@ -65,6 +69,13 @@ sub bpom_rpo_check_label_design {
             next;
         }
 
+        my $filesize = -s $file;
+        if ($filesize < 100*1024) {
+            push @warnings, {file=>$file, message=>"File size very small (<100k), perhaps increase quality?"};
+        } elsif ($filesize > 5*1024*1024) {
+            push @errors, {file=>$file, message=>"File size too large (>5M)"};
+        }
+
         # because File::MimeInfo::Magic will report mime='inode/symlink' for symlink
         my $realfile = -l $file ? readlink($file) : $file;
         my $mime_type = File::MimeInfo::Magic::mimetype($realfile);
@@ -97,7 +108,7 @@ App::BPOMUtils::RPO::Checker - Various checker utilities to help with Processed
 
 =head1 VERSION
 
-This document describes version 0.003 of App::BPOMUtils::RPO::Checker (from Perl distribution App-BPOMUtils-RPO-Checker), released on 2023-01-27.
+This document describes version 0.004 of App::BPOMUtils::RPO::Checker (from Perl distribution App-BPOMUtils-RPO-Checker), released on 2023-01-27.
 
 =head1 SYNOPSIS
 
